@@ -22,6 +22,30 @@ from os.path import join as pj
 import glob
 import time
 
+
+__all__ = ["shellcmd", "checkParam"]
+
+
+def checkParam(param, valid_values):
+    """Checks that the value of param is amongst valid
+
+    :param param: a parameter to be checked
+    :param list valid_values: a list of values 
+
+    ::
+
+        checkParam(1, [1,2,3])
+        checkParam(mode, ["on", "off"])
+    """
+    if isinstance(valid_values, list) == False:
+        raise TypeError("the valid_values second argument must be a list of valid values")
+
+    if param not in valid_values:
+        msg = "Incorrect value provided (%s)" % param
+        msg += "    Correct values are %s" % valid_values
+        raise ValueError(msg)
+    
+
 def shellcmd(cmd, show=True, verbose=False):
     """An alias to run system commands.
 
@@ -55,3 +79,4 @@ def shellcmd(cmd, show=True, verbose=False):
         raise Exception("Error:: Command (%s) failed. Error message is %s" % (cmd, e))
 
 
+
